@@ -21,6 +21,11 @@ class EmitRecorder(IEmitRecorder):
         return not self.length
 
     def save(self, result):
+        """
+        保存结果
+        :param result:
+        :return:
+        """
         self._results.append(result)
 
     def __iter__(self):
@@ -28,6 +33,9 @@ class EmitRecorder(IEmitRecorder):
             for _, result in enumerate(self._results):
                 yield result
 
+    def __str__(self):
+        return str(self._results)
+
 
 class EmitRecorderChain(IEmitRecorder):
 
@@ -35,6 +43,11 @@ class EmitRecorderChain(IEmitRecorder):
         self._results = EmitRecorder()
 
     def save(self, result: IEmitRecorder):
+        """
+        保存结果记录器
+        :param result:
+        :return:
+        """
         if not self._is_recoder(result):
             return
         self._results.save(result)
