@@ -6,7 +6,7 @@
 from typing import Callable, Dict, Optional, Tuple
 from functools import partial, wraps
 
-from f1z1_common import CoroOrFunction, TimestampUnit
+from f1z1_common import CoroOrFunction, UnitOfTime
 
 from ..components import CountGenerator, SpeedTypes, SpeedUnit, Size, Speed, EmitTaskQueue, EmitRecorder
 from .worker import EmitWorker
@@ -17,7 +17,7 @@ WrappedReturn = Callable[[Optional[Tuple], Optional[Dict]], EmitWorker]
 
 def _factory(speed: SpeedTypes,
              count: Size = 1,
-             unit: SpeedUnit = TimestampUnit.MILLISECOND,
+             unit: SpeedUnit = UnitOfTime.MILLISECOND,
              thread_workers: int = None):
     speed = Speed(speed, unit)
     return partial(
@@ -31,7 +31,7 @@ def _factory(speed: SpeedTypes,
 
 def emit_decorate(speed: SpeedTypes,
                   count: Size = 1,
-                  unit: SpeedUnit = TimestampUnit.MILLISECOND,
+                  unit: SpeedUnit = UnitOfTime.MILLISECOND,
                   thread_workers: int = None) -> DecorateReturn:
     def decorator(func: CoroOrFunction) -> WrappedReturn:
         @wraps(func)
